from flask import Flask, jsonify, render_template
import serial
import database as db

dash = Flask(__name__)

def recv_data():
    try:
        ser = serial.Serial('/dev/ttyACM0', timeout=1)
        yield ser.readline()
    except serial.SerialTimeoutException:
        pass
    except serial.SerialException:
        yield "E"

@dash.route("/")
def dashboard(): 
    drinks = db.getDrinks()
    return render_template('dashboard.html', sinks=drinks)

refresh = False

@dash.route('/update')
def update():
    global refresh
    refresh = True
    return "OK"

@dash.route('/test')
def test():
    return render_template("base.html", base = {'page': "Testowa", 'errorMsg': "Test"})

@dash.route('/json')
def action():
    global refresh
    data = recv_data().__next__()
    packet = {}
    if data == "E":
        packet["system"] = {"state": "Błąd!", "info": "Brak połączenia"}
    if refresh:
        packet['refresh'] = True
        refresh = False
    return jsonify(packet)

if __name__ == '__main__':
    dash.run(debug=True, port=5555, threaded=True, host="0.0.0.0")